@@ -206,7 +206,7 @@ class Store(StorageInterface):
             count = query.count()
             logging.debug('count is: %s', count)
             self.environ['tiddlyweb.mappingsql.count'] = count
-            stiddlers = query.slice(slice_index, limit).all()
+            stiddlers = query.slice(slice_index, slice_index + limit).all()
         else:
             stiddlers = []
 
